#ifndef PARAMS_HH
#define PARAMS_HH
/*
  Parameter for Aligner
*/

class AnchorConstraints;

class AlignerParams {  
public:
    typedef size_t size_type;

    const bool no_lonely_pairs; // no lonely pairs option
  
    const bool STRUCT_LOCAL; // allow exclusions for maximizing alignment of connected substructures 
    const bool SEQU_LOCAL; // maximize alignment of subsequences
  
    const bool DO_TRACE;

    const size_type max_diff;

    const size_type max_diff_am;
    
    const int stacking;

    const AnchorConstraints &constraints;
    
    AlignerParams(bool _no_lonely_pairs, bool _STRUCT_LOCAL, 
		  bool _SEQU_LOCAL, int _max_diff, int _max_diff_am,
		  bool _stacking,
		  const AnchorConstraints &_constraints
	):
	no_lonely_pairs(_no_lonely_pairs),
	STRUCT_LOCAL(_STRUCT_LOCAL),
	SEQU_LOCAL(_SEQU_LOCAL),
	DO_TRACE(true),
	max_diff(_max_diff),
	max_diff_am(_max_diff_am),
	stacking(_stacking),
	constraints(_constraints)
    {}
  
};


/*!
  parameters for the basepairs class

  contains the necessary information for determining the
  significant basepairs and computing their weights
*/
class BasePairsParams {
public:
    const double min_prob; //!< only pairs with a probability of at least min_prob are taken into account
    
    BasePairsParams(double _min_prob)
      :
	min_prob(_min_prob)
    {}
};

#endif // PARAMS_HH
